@@ -1603,6 +1603,8 @@ pub struct MergeRequest {
     pub assignee: Option<UserBasic>,
     /// The assignees of the merge request.
     pub assignees: Option<Vec<UserBasic>>,
+    /// The reviewers of the merge request.
+    pub reviewers: Option<Vec<UserBasic>>,
     /// The ID of the project hosting the source branch.
     pub source_project_id: ProjectId,
     /// The ID of the project hosting the target branch.
@@ -1709,6 +1711,8 @@ pub struct MergeRequestChanges {
     pub assignee: Option<UserBasic>,
     /// The assignees of the merge request.
     pub assignees: Option<Vec<UserBasic>>,
+    /// The reviewers of the merge request.
+    pub reviewers: Option<Vec<UserBasic>>,
     /// The ID of the project hosting the source branch.
     pub source_project_id: ProjectId,
     /// The ID of the project hosting the target branch.
@@ -1793,6 +1797,7 @@ impl From<MergeRequestChanges> for MergeRequest {
             author: mr.author,
             assignee: mr.assignee,
             assignees: mr.assignees,
+            reviewers: mr.reviewers,
             source_project_id: mr.source_project_id,
             target_project_id: mr.target_project_id,
             labels: mr.labels,
@@ -2452,6 +2457,8 @@ impl_id!(PipelineId, "Type-safe pipeline ID.");
 pub struct PipelineBasic {
     /// The ID of the pipeline.
     pub id: PipelineId,
+    /// The ID of the project holding the pipeline.
+    pub project_id: ProjectId,
     #[serde(rename = "ref")]
     /// The name of the reference that was tested.
     pub ref_: Option<String>,
@@ -2472,6 +2479,8 @@ pub struct PipelineBasic {
 pub struct Pipeline {
     /// The ID of the pipeline.
     pub id: PipelineId,
+    /// The ID of the project holding the pipeline.
+    pub project_id: ProjectId,
     /// The object ID that was tested.
     pub sha: ObjectId,
     #[serde(rename = "ref")]
